@@ -21,9 +21,10 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.206';
+our $VERSION = '1.207';
 
 use Quiq::Hash;
+use Encode ();
 use Quiq::Path;
 use Quiq::Image;
 use Quiq::Array;
@@ -53,7 +54,7 @@ dieses Objekt zurück.
 sub new {
     my ($class,$path) = @_;
 
-    if (!-e $path) {
+    if (!-e Encode::encode('utf-8',$path)) {
         $class->throw(
              'IMAGE-00001: File not found',
              Path => $path,
@@ -447,7 +448,7 @@ sub analyzeFile {
 
 =head1 VERSION
 
-1.206
+1.207
 
 =head1 AUTHOR
 
@@ -455,7 +456,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022 Frank Seitz
+Copyright (C) 2023 Frank Seitz
 
 =head1 LICENSE
 
