@@ -59,10 +59,11 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.206';
+our $VERSION = '1.207';
 
 use Quiq::CommandLine;
 use Quiq::Shell;
+use Encode ();
 use Quiq::Ipc;
 use Quiq::Unindent;
 use Quiq::Css;
@@ -159,6 +160,7 @@ sub css {
     );
 
     my $rules = Quiq::Shell->exec($c->command,-capture=>'stdout');
+    $rules = Encode::decode('utf-8',$rules); # Wir erwarten UTF-8
 
     # Bestimme Hintergrundfarbe, diese muss existieren, da die
     # Forderungrundfarben darauf abgestimmt sind.
@@ -231,6 +233,7 @@ sub html {
         -l => $lang, # = lexer
     );
     my $html = Quiq::Ipc->filter($c->command,$code);
+    $html = Encode::decode('utf-8',$html); # Wir erwarten UTF-8
 
     # Nicht benötigte "Umrahmung" des gehighlighteten Code entfernen
 
@@ -373,7 +376,7 @@ sub stylesPage {
 
 =head1 VERSION
 
-1.206
+1.207
 
 =head1 AUTHOR
 
@@ -381,7 +384,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022 Frank Seitz
+Copyright (C) 2023 Frank Seitz
 
 =head1 LICENSE
 
