@@ -106,7 +106,7 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.206';
+our $VERSION = '1.207';
 
 use Quiq::Path;
 use Quiq::TimeLapse::File;
@@ -159,7 +159,7 @@ sub new {
     # Bilddateien ermitteln
 
     my @images;
-    for my $file (Quiq::Path->find($dir,-type=>'f')) {
+    for my $file (Quiq::Path->find($dir,-type=>'f',-decode=>'utf-8')) {
         if ($file =~ /range.def$/) {
             next;
         }
@@ -963,7 +963,7 @@ sub reorganize {
 
 =head1 VERSION
 
-1.206
+1.207
 
 =head1 AUTHOR
 
@@ -971,7 +971,7 @@ Frank Seitz, L<http://fseitz.de/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2022 Frank Seitz
+Copyright (C) 2023 Frank Seitz
 
 =head1 LICENSE
 
